==> freecad_0.18.4+dfsg2.orig.tar.xz: FreeCAD-0.18.4/src/Mod/Web/Gui/Resources/translations/Web_ko.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ko" sourcelanguage="en">
  <context>
    <name>CmdWebBrowserBack</name>
    <message>
      <location filename="../../Command.cpp" line="76"/>
      <source>Web</source>
      <translation>웹</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="77"/>
      <source>Previous page</source>
      <translation>이전 페이지</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="78"/>
      <source>Go back to the previous page</source>
      <translation>이전 페이지로 돌아가기</translation>
    </message>
  </context>
  <context>
    <name>CmdWebBrowserNext</name>
    <message>
      <location filename="../../Command.cpp" line="105"/>
      <source>Web</source>
      <translation>웹</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="106"/>
      <source>Next page</source>
      <translation>다음 페이지</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="107"/>
      <source>Go to the next page</source>
      <translation>다음 페이지로 이동</translation>
    </message>
  </context>
  <context>
    <name>CmdWebBrowserRefresh</name>
    <message>
      <location filename="../../Command.cpp" line="134"/>
      <source>Web</source>
      <translation>웹</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="135"/>
      <location filename="../../Command.cpp" line="136"/>
      <source>Refresh web page</source>
      <translation>웹 페이지 새로 고침</translation>
    </message>
  </context>
  <context>
    <name>CmdWebBrowserStop</name>
    <message>
      <location filename="../../Command.cpp" line="162"/>
      <source>Web</source>
      <translation>웹</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="163"/>
      <location filename="../../Command.cpp" line="164"/>
      <source>Stop loading</source>
      <translation>불러오기 중지</translation>
    </message>
  </context>
  <context>
    <name>CmdWebBrowserZoomIn</name>
    <message>
      <location filename="../../Command.cpp" line="192"/>
      <source>Web</source>
      <translation>웹</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="193"/>
      <location filename="../../Command.cpp" line="194"/>
      <source>Zoom in</source>
      <translation>확대</translation>
    </message>
  </context>
  <context>
    <name>CmdWebBrowserZoomOut</name>
    <message>
      <location filename="../../Command.cpp" line="221"/>
      <source>Web</source>
      <translation>웹</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="222"/>
      <location filename="../../Command.cpp" line="223"/>
      <source>Zoom out</source>
      <translation>축소</translation>
    </message>
  </context>
  <context>
    <name>CmdWebOpenWebsite</name>
    <message>
      <location filename="../../Command.cpp" line="50"/>
      <source>Web</source>
      <translation>웹</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="51"/>
      <source>Open website...</source>
      <translation>웹사이트 열기...</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="52"/>
      <source>Opens a website in FreeCAD</source>
      <translation>FreeCAD에서 웹사이트를 엽니다.</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <location filename="../../AppWebGui.cpp" line="80"/>
      <location filename="../../BrowserView.cpp" line="441"/>
      <source>Browser</source>
      <translation>브라우저</translation>
    </message>
    <message>
      <location filename="../../BrowserView.cpp" line="338"/>
      <source>File does not exist!</source>
      <translation>파일이 존재 하지 않습니다!</translation>
    </message>
  </context>
  <context>
    <name>WebGui::BrowserView</name>
    <message>
      <location filename="../../BrowserView.cpp" line="329"/>
      <location filename="../../BrowserView.cpp" line="334"/>
      <source>Error</source>
      <translation>에러</translation>
    </message>
    <message>
      <location filename="../../BrowserView.cpp" line="334"/>
      <source>There were errors while loading the file. Some data might have been modified or not recovered at all. Look in the report view for more specific information about the objects involved.</source>
      <translation type="unfinished">There were errors while loading the file. Some data might have been modified or not recovered at all. Look in the report view for more specific information about the objects involved.</translation>
    </message>
    <message>
      <location filename="../../BrowserView.cpp" line="412"/>
      <source>Loading %1...</source>
      <translation>%1 로딩 중...</translation>
    </message>
  </context>
  <context>
    <name>WebGui::WebView</name>
    <message>
      <location filename="../../BrowserView.cpp" line="185"/>
      <source>Open in External Browser</source>
      <translation>다른 브라우저에서 열기</translation>
    </message>
    <message>
      <location filename="../../BrowserView.cpp" line="189"/>
      <source>Open in new window</source>
      <translation>새 창에서 열기</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../Workbench.cpp" line="46"/>
      <source>Navigation</source>
      <translation>탐색</translation>
    </message>
  </context>
</TS>

==> freecad_0.19.1+dfsg1.orig.tar.xz: FreeCAD-0.19.1/src/Mod/Web/Gui/Resources/translations/Web_ko.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ko" sourcelanguage="en">
  <context>
    <name>CmdWebBrowserBack</name>
    <message>
      <location filename="../../Command.cpp" line="76"/>
      <source>Web</source>
      <translation>웹</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="77"/>
      <source>Previous page</source>
      <translation>이전 페이지</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="78"/>
      <source>Go back to the previous page</source>
      <translation>이전 페이지로 돌아가기</translation>
    </message>
  </context>
  <context>
    <name>CmdWebBrowserNext</name>
    <message>
      <location filename="../../Command.cpp" line="105"/>
      <source>Web</source>
      <translation>웹</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="106"/>
      <source>Next page</source>
      <translation>다음 페이지</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="107"/>
      <source>Go to the next page</source>
      <translation>다음 페이지로 이동</translation>
    </message>
  </context>
  <context>
    <name>CmdWebBrowserRefresh</name>
    <message>
      <location filename="../../Command.cpp" line="134"/>
      <source>Web</source>
      <translation>웹</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="135"/>
      <location filename="../../Command.cpp" line="136"/>
      <source>Refresh web page</source>
      <translation>웹 페이지 새로 고침</translation>
    </message>
  </context>
  <context>
    <name>CmdWebBrowserSetURL</name>
    <message>
      <location filename="../../Command.cpp" line="250"/>
      <source>Web</source>
      <translation>웹</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="251"/>
      <location filename="../../Command.cpp" line="252"/>
      <source>Set URL</source>
      <translation>URL 설정</translation>
    </message>
  </context>
  <context>
    <name>CmdWebBrowserStop</name>
    <message>
      <location filename="../../Command.cpp" line="162"/>
      <source>Web</source>
      <translation>웹</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="163"/>
      <location filename="../../Command.cpp" line="164"/>
      <source>Stop loading</source>
      <translation>불러오기 중지</translation>
    </message>
  </context>
  <context>
    <name>CmdWebBrowserZoomIn</name>
    <message>
      <location filename="../../Command.cpp" line="192"/>
      <source>Web</source>
      <translation>웹</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="193"/>
      <location filename="../../Command.cpp" line="194"/>
      <source>Zoom in</source>
      <translation>확대</translation>
    </message>
  </context>
  <context>
    <name>CmdWebBrowserZoomOut</name>
    <message>
      <location filename="../../Command.cpp" line="221"/>
      <source>Web</source>
      <translation>웹</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="222"/>
      <location filename="../../Command.cpp" line="223"/>
      <source>Zoom out</source>
      <translation>축소</translation>
    </message>
  </context>
  <context>
    <name>CmdWebOpenWebsite</name>
    <message>
      <location filename="../../Command.cpp" line="50"/>
      <source>Web</source>
      <translation>웹</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="51"/>
      <source>Open website...</source>
      <translation>웹사이트 열기...</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="52"/>
      <source>Opens a website in FreeCAD</source>
      <translation>FreeCAD에서 웹사이트를 엽니다.</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <location filename="../../AppWebGui.cpp" line="88"/>
      <location filename="../../BrowserView.cpp" line="748"/>
      <source>Browser</source>
      <translation>브라우저</translation>
    </message>
    <message>
      <location filename="../../BrowserView.cpp" line="563"/>
      <source>File does not exist!</source>
      <translation>파일이 존재 하지 않습니다!</translation>
    </message>
  </context>
  <context>
    <name>WebGui::BrowserView</name>
    <message>
      <location filename="../../BrowserView.cpp" line="551"/>
      <location filename="../../BrowserView.cpp" line="556"/>
      <location filename="../../BrowserView.cpp" line="559"/>
      <source>Error</source>
      <translation>에러</translation>
    </message>
    <message>
      <location filename="../../BrowserView.cpp" line="556"/>
      <source>There were errors while loading the file. Some data might have been modified or not recovered at all. Look in the report view for more specific information about the objects involved.</source>
      <translation>파일을 불러오는 도중 문제가 생겼습니다. 일부 데이터가 수정되거나 전혀 복구되지 않았을 수 있습니다. 해당 개체에 대한 보다 구체적인 정보를 확인하려면 보고서를 보세요.</translation>
    </message>
    <message>
      <location filename="../../BrowserView.cpp" line="559"/>
      <source>There were serious errors while loading the file. Some data might have been modified or not recovered at all. Saving the project will most likely result in loss of data.</source>
      <translation type="unfinished">There were serious errors while loading the file. Some data might have been modified or not recovered at all. Saving the project will most likely result in loss of data.</translation>
    </message>
    <message>
      <location filename="../../BrowserView.cpp" line="719"/>
      <source>Loading %1...</source>
      <translation>%1 로딩 중...</translation>
    </message>
  </context>
  <context>
    <name>WebGui::WebView</name>
    <message>
      <location filename="../../BrowserView.cpp" line="308"/>
      <source>Open in External Browser</source>
      <translation>다른 브라우저에서 열기</translation>
    </message>
    <message>
      <location filename="../../BrowserView.cpp" line="312"/>
      <source>Open in new window</source>
      <translation>새 창에서 열기</translation>
    </message>
    <message>
      <location filename="../../BrowserView.cpp" line="344"/>
      <source>View source</source>
      <translation>소스 보기</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../Workbench.cpp" line="46"/>
      <source>Navigation</source>
      <translation>탐색</translation>
    </message>
  </context>
</TS>
